==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ListPanelTemplateHeightRequestedEventArgsDescription } from "./ListPanelTemplateHeightRequestedEventArgsDescription";
/**
 * @hidden
 */
export let ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.a == null) {
                ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.c(ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.a);
            }
            if (a.j(ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("DataRow", "Number:int");
            a.item("DataItemRef", "(w:DataItem,wf:DataItem)DataRef");
            a.item("Height", "Number:double");
        }
        static d(a) {
            ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.b(a);
            a.aa("ListPanelTemplateHeightRequestedEventArgs", () => new ListPanelTemplateHeightRequestedEventArgsDescription());
            a.z("ListPanelTemplateHeightRequestedEventArgs", ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.a);
        }
    }
    ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata, 'ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata');
    ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.a = null;
    return ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ListPanelTemplateHeightRequestedEventArgsDescription } from "./ListPanelTemplateHeightRequestedEventArgsDescription";
/**
 * @hidden
 */
export let ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.a == null) {
                ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.c(ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.a);
            }
            if (a.k(ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("DataRow", "Number:int");
            a.item("DataItemRef", "(w:DataItem,wf:DataItem)DataRef");
            a.item("Height", "Number:double");
        }
        static d(a) {
            ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.b(a);
            a.ac("ListPanelTemplateHeightRequestedEventArgs", () => new ListPanelTemplateHeightRequestedEventArgsDescription());
            a.ab("ListPanelTemplateHeightRequestedEventArgs", ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.a);
        }
    }
    ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata, 'ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata');
    ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.a = null;
    return ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata;
})();
